==> thermoo-8.0.0-sources.jar: com/github/thedeathlycow/thermoo/impl/component/TemperatureEffectsComponent.java <==
package com.github.thedeathlycow.thermoo.impl.component;

import com.github.thedeathlycow.thermoo.api.temperature.effects.ConfiguredTemperatureEffect;
import com.github.thedeathlycow.thermoo.impl.temperature.effect.TemperatureEffectManager;
import org.ladysnake.cca.api.v3.component.Component;
import org.ladysnake.cca.api.v3.component.tick.ServerTickingComponent;

import java.util.HashMap;
import java.util.Map;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1309;
import net.minecraft.class_2960;

public class TemperatureEffectsComponent implements Component, ServerTickingComponent {

    private final Map<class_2960, Settings> effectsSettings = new HashMap<>();

    private final class_1309 provider;

    public TemperatureEffectsComponent(class_1309 provider) {
        this.provider = provider;
    }

    @Override
    public void readData(class_11368 readView) {
        // nothing to read
    }

    @Override
    public void writeData(class_11372 writeView) {
        // nothing to write
    }

    @Override
    public void serverTick() {
        var availableEffects = TemperatureEffectManager.INSTANCE.getEffectsEntriesForEntity(provider);
        for (TemperatureEffectManager.EntityTypeCacheEntry effectEntry : availableEffects) {
            Settings settings = this.effectsSettings.computeIfAbsent(effectEntry.id(), ignored -> new Settings());
            boolean wasApplied = settings.applied;
            ConfiguredTemperatureEffect<?> effect = effectEntry.effect();

            if (effect.apply(provider)) {
                settings.applied = true;
            } else {
                settings.applied = false;
            }

            if (wasApplied && !settings.applied) {
                effect.remove(provider);
            }
        }
    }

    private static class Settings {
        private boolean applied = false;
    }
}

==> thermoo-9.0.0-sources.jar: com/github/thedeathlycow/thermoo/impl/component/TemperatureEffectsComponent.java <==
package com.github.thedeathlycow.thermoo.impl.component;

import com.github.thedeathlycow.thermoo.api.temperature.effects.ConfiguredTemperatureEffect;
import com.github.thedeathlycow.thermoo.impl.temperature.effect.TemperatureEffectManager;
import org.ladysnake.cca.api.v3.component.Component;
import org.ladysnake.cca.api.v3.component.tick.ServerTickingComponent;

import java.util.HashMap;
import java.util.Map;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1309;
import net.minecraft.class_2960;

public class TemperatureEffectsComponent implements Component, ServerTickingComponent {

    private final Map<class_2960, Settings> effectsSettings = new HashMap<>();

    private final class_1309 provider;

    public TemperatureEffectsComponent(class_1309 provider) {
        this.provider = provider;
    }

    @Override
    public void readData(class_11368 readView) {
        // nothing to read
    }

    @Override
    public void writeData(class_11372 writeView) {
        // nothing to write
    }

    @Override
    public void serverTick() {
        var availableEffects = TemperatureEffectManager.INSTANCE.getEffectsEntriesForEntity(provider);
        for (TemperatureEffectManager.EntityTypeCacheEntry effectEntry : availableEffects) {
            Settings settings = this.effectsSettings.computeIfAbsent(effectEntry.location(), ignored -> new Settings());
            boolean wasApplied = settings.applied;
            ConfiguredTemperatureEffect<?> effect = effectEntry.effect();

            if (effect.apply(provider)) {
                settings.applied = true;
            } else {
                settings.applied = false;
            }

            if (wasApplied && !settings.applied) {
                effect.remove(provider);
            }
        }
    }

    private static class Settings {
        private boolean applied = false;
    }
}
